@@ -7,6 +7,7 @@ use debugless_unwrap::DebuglessUnwrap as _;
 use indexmap::{map, IndexMap};
 use smartstring::alias::String;
 use std::{
+	borrow::Borrow,
 	hash::Hash,
 	iter::Peekable,
 	ops::{Deref, Range},
@@ -76,6 +77,10 @@ impl<'a, Position> Taml<'a, Position> {
 #[derive(Debug, Clone)]
 pub enum TamlValue<'a, Position> {
 	String(Cow<'a, String, str>),
+	Decoded {
+		encoding: Cow<'a, String, str>,
+		decoded: Cow<'a, String, str>,
+	},
 	Integer(&'a str),
 	Float(&'a str),
 	List(List<'a, Position>),
@@ -142,6 +147,12 @@ pub struct Key<'a, Position> {
 	pub span: Range<Position>,
 }
 
+impl<'a, Position> Borrow<str> for Key<'a, Position> {
+	fn borrow(&self) -> &str {
+		self.name.as_ref()
+	}
+}
+
 impl<'a, Position> Deref for Key<'a, Position> {
 	type Target = str;
 	fn deref(&self) -> &Self::Target {
@@ -1268,6 +1279,10 @@ fn parse_value<'a, Position: Clone>(
 				value: TamlValue::String(str),
 				span,
 			},
+			(lexerToken::Decoded((encoding, decoded)), span) => Taml {
+				value: TamlValue::Decoded { encoding, decoded },
+				span,
+			},
 			(lexerToken::Float(str), span) => Taml {
 				value: TamlValue::Float(str),
 				span,
